# Table of Contents

- [system-modeling-guidelines](<./system-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [System Modeling Guidelines](<./System-Modeling-Guidelines.md>)
  - [Definition](<./System-Modeling-Guidelines/Definition.md>)
  - [Purpose](<./System-Modeling-Guidelines/Purpose.md>)
  - [Capturing Systems with SAP Discovery](<./System-Modeling-Guidelines/Capturing-Systems-with-SAP-Discovery.md>)
  - [Capturing Systems from ServiceNow](<./System-Modeling-Guidelines/Capturing-Systems-from-ServiceNow.md>)
  - [Bringing Together SAP Discovery and ServiceNow Data](<./System-Modeling-Guidelines/Bringing-Together-SAP-Discovery-and-ServiceNow-Data.md>)
  - [Activating the System Fact Sheet](<./System-Modeling-Guidelines/Activating-the-System-Fact-Sheet.md>)
  - [Antipatterns](<./System-Modeling-Guidelines/Antipatterns.md>)
  - [Related Information](<./System-Modeling-Guidelines/Related-Information.md>)
  - [Was this page helpful?](<./System-Modeling-Guidelines/Was-this-page-helpful.md>)
